## Security

GitGuardian takes the security of our software products and services seriously, and that includes all source code repositories managed through our GitHub organization.

If you believe you have found a security vulnerability in any GitGuardian-owned repository, please report it using our [Vulnerability Disclosure Portal](https://vdp.gitguardian.com).

## Preferred Languages

We prefer all communications to be in English or French.
